==> 0.0.1.tar.gz: lib/src/widgets/_impl/_date_picker_mode_toggle_button.dart <==
part of '../calendar_date_picker2.dart';

/// A button that used to toggle the [DatePickerMode] for a date picker.
///
/// This appears above the calendar grid and allows the user to toggle the
/// [DatePickerMode] to display either the calendar view or the year list.
class _DatePickerModeToggleButton extends StatefulWidget {
  const _DatePickerModeToggleButton({
    required this.mode,
    required this.title,
    required this.title2,
    required this.onTitlePressed,
    required this.config,
  });

  /// The current display of the calendar picker.
  final DatePickerMode mode;

  /// The text that displays the current month/year being viewed.
  final String title;
  final String title2;

  /// The callback when the title is pressed.
  final VoidCallback onTitlePressed;

  /// The calendar configurations
  final CalendarDatePicker2Config config;

  @override
  _DatePickerModeToggleButtonState createState() =>
      _DatePickerModeToggleButtonState();
}

class _DatePickerModeToggleButtonState
    extends State<_DatePickerModeToggleButton>
    with SingleTickerProviderStateMixin {
  late AnimationController _controller;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      value: widget.mode == DatePickerMode.year ? 0.5 : 0,
      upperBound: 0.5,
      duration: const Duration(milliseconds: 200),
      vsync: this,
    );
  }

  @override
  void didUpdateWidget(_DatePickerModeToggleButton oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.mode == widget.mode) {
      return;
    }

    if (widget.mode == DatePickerMode.year) {
      _controller.forward();
    } else {
      _controller.reverse();
    }
  }

  @override
  Widget build(BuildContext context) {
    final ColorScheme colorScheme = Theme.of(context).colorScheme;
    final TextTheme textTheme = Theme.of(context).textTheme;
    final Color controlColor = colorScheme.onSurface.withOpacity(0.60);
    var datePickerOffsetPadding = _monthNavButtonsWidth;
    if (widget.config.centerAlignModePicker == true) {
      datePickerOffsetPadding /= 2;
    }
    print(widget.title2);
    return Container(
      padding: widget.config.centerAlignModePicker == true
          ? EdgeInsets.zero
          : const EdgeInsetsDirectional.only(start: 16, end: 4),
      height: (widget.config.controlsHeight ?? _subHeaderHeight),
      child: Row(
        children: <Widget>[
          if (widget.mode == DatePickerMode.day &&
              widget.config.centerAlignModePicker == true)
            // Give space for the prev/next month buttons that are underneath this row
            SizedBox(width: datePickerOffsetPadding),
          Flexible(
            child: Semantics(
              label: MaterialLocalizations.of(context).selectYearSemanticsLabel,
              excludeSemantics: true,
              button: true,
              child: SizedBox(
                height: (widget.config.controlsHeight ?? _subHeaderHeight),
                child: InkWell(
                  onTap: widget.config.disableModePicker == true
                      ? null
                      : widget.onTitlePressed,
                  child: Padding(
                    padding: EdgeInsets.symmetric(
                        horizontal: widget.config.centerAlignModePicker == true
                            ? 0
                            : 8),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Container(
                          width: 77,
                          height: 40,
                          decoration: const BoxDecoration(
                            borderRadius: BorderRadius.all(Radius.circular(5)),
                            color: Colors.white,
                          ),
                          child: Row(
                            mainAxisAlignment:
                                widget.config.centerAlignModePicker == true
                                    ? MainAxisAlignment.center
                                    : MainAxisAlignment.start,
                            children: <Widget>[
                              Flexible(
                                child: Text(
                                  widget.title,
                                  overflow: TextOverflow.ellipsis,
                                  style: const TextStyle(
                                      color: Colors.black,
                                      fontWeight: FontWeight.w700,
                                      fontSize: 16),
                                  // widget.config.controlsTextStyle ??
                                  //     textTheme.titleSmall?.copyWith(
                                  //       color: controlColor,
                                  //     ),
                                ),
                              ),
                              widget.config.disableModePicker == true
                                  ? const SizedBox()
                                  : RotationTransition(
                                      turns: _controller,
                                      child: widget
                                              .config.customModePickerIcon ??
                                          const Icon(
                                            Icons.arrow_drop_down,
                                            color:
                                                Color.fromRGBO(150, 198, 15, 1),
                                            size: 30,
                                          ),
                                    ),
                            ],
                          ),
                        ),
                        // const Spacer(flex: 3),
                        const SizedBox(width: 5),
                        Container(
                          width: 77,
                          height: 40,
                          decoration: const BoxDecoration(
                            borderRadius: BorderRadius.all(Radius.circular(5)),
                            color: Colors.white,
                          ),
                          child: Row(
                            mainAxisAlignment:
                                widget.config.centerAlignModePicker == true
                                    ? MainAxisAlignment.center
                                    : MainAxisAlignment.start,
                            children: <Widget>[
                              Flexible(
                                child: Text(
                                  widget.title2,
                                  overflow: TextOverflow.ellipsis,
                                  style: const TextStyle(
                                      color: Colors.black,
                                      fontWeight: FontWeight.w700,
                                      fontSize: 16),
                                  // widget.config.controlsTextStyle ??
                                  //     textTheme.titleSmall?.copyWith(
                                  //       color: controlColor,
                                  //     ),
                                ),
                              ),
                              widget.config.disableModePicker == true
                                  ? const SizedBox()
                                  : RotationTransition(
                                      turns: _controller,
                                      child: widget
                                              .config.customModePickerIcon ??
                                          const Icon(
                                            Icons.arrow_drop_down,
                                            color:
                                                Color.fromRGBO(150, 198, 15, 1),
                                            size: 30,
                                          ),
                                    ),
                            ],
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ),
          if (widget.mode == DatePickerMode.day)
            // Give space for the prev/next month buttons that are underneath this row
            SizedBox(width: datePickerOffsetPadding),
        ],
      ),
    );
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }
}

==> 0.0.4.tar.gz: lib/src/widgets/_impl/_date_picker_mode_toggle_button.dart <==
part of '../calendar_date_picker2.dart';

/// A button that used to toggle the [DatePickerMode] for a date picker.
///
/// This appears above the calendar grid and allows the user to toggle the
/// [DatePickerMode] to display either the calendar view or the year list.
class _DatePickerModeToggleButton extends StatefulWidget {
  const _DatePickerModeToggleButton({
    required this.mode,
    required this.title,
    // required this.title2,
    required this.onTitlePressed,
    required this.config,
  });

  /// The current display of the calendar picker.
  final DatePickerMode mode;

  /// The text that displays the current month/year being viewed.
  final String title;
  // final String title2;

  /// The callback when the title is pressed.
  final VoidCallback onTitlePressed;

  /// The calendar configurations
  final CalendarDatePicker2Config config;

  @override
  _DatePickerModeToggleButtonState createState() =>
      _DatePickerModeToggleButtonState();
}

class _DatePickerModeToggleButtonState
    extends State<_DatePickerModeToggleButton>
    with SingleTickerProviderStateMixin {
  late AnimationController _controller;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      value: widget.mode == DatePickerMode.year ? 0.5 : 0,
      upperBound: 0.5,
      duration: const Duration(milliseconds: 200),
      vsync: this,
    );
  }

  @override
  void didUpdateWidget(_DatePickerModeToggleButton oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.mode == widget.mode) {
      return;
    }

    if (widget.mode == DatePickerMode.year) {
      _controller.forward();
    } else {
      _controller.reverse();
    }
  }

  @override
  Widget build(BuildContext context) {
    final ColorScheme colorScheme = Theme.of(context).colorScheme;
    final TextTheme textTheme = Theme.of(context).textTheme;
    final Color controlColor = colorScheme.onSurface.withOpacity(0.60);
    var datePickerOffsetPadding = _monthNavButtonsWidth;
    if (widget.config.centerAlignModePicker == true) {
      datePickerOffsetPadding /= 2;
    }
    // print(widget.title);
    return Container(
      padding: widget.config.centerAlignModePicker == true
          ? EdgeInsets.zero
          : const EdgeInsetsDirectional.only(start: 16, end: 4),
      height: (widget.config.controlsHeight ?? _subHeaderHeight),
      child: Row(
        children: <Widget>[
          if (widget.mode == DatePickerMode.day &&
              widget.config.centerAlignModePicker == true)
            // Give space for the prev/next month buttons that are underneath this row
            SizedBox(width: datePickerOffsetPadding),
          Flexible(
            child: Semantics(
              label: MaterialLocalizations.of(context).selectYearSemanticsLabel,
              excludeSemantics: true,
              button: true,
              //Aqui abajo esta el desmadre, here
              child: SizedBox(
                height: (widget.config.controlsHeight ?? _subHeaderHeight),
                child: InkWell(
                  onTap: widget.config.disableModePicker == true
                      ? null
                      : widget.onTitlePressed,
                  child: Padding(
                    padding: EdgeInsets.symmetric(
                        horizontal: widget.config.centerAlignModePicker == true
                            ? 0
                            : 8),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Container(
                          width: 77,
                          height: 40,
                          decoration: const BoxDecoration(
                            borderRadius: BorderRadius.all(Radius.circular(5)),
                            color: Colors.white,
                          ),
                          child: Row(
                            mainAxisAlignment:
                                widget.config.centerAlignModePicker == true
                                    ? MainAxisAlignment.center
                                    : MainAxisAlignment.start,
                            children: <Widget>[
                              Flexible(
                                child: Text(
                                  widget.title,
                                  overflow: TextOverflow.ellipsis,
                                  style: const TextStyle(
                                      color: Colors.black,
                                      fontWeight: FontWeight.w700,
                                      fontSize: 16),
                                  // widget.config.controlsTextStyle ??
                                  //     textTheme.titleSmall?.copyWith(
                                  //       color: controlColor,
                                  //     ),
                                ),
                              ),
                              widget.config.disableModePicker == true
                                  ? const SizedBox()
                                  : RotationTransition(
                                      turns: _controller,
                                      child: widget
                                              .config.customModePickerIcon ??
                                          const Icon(
                                            Icons.arrow_drop_down,
                                            color:
                                                Color.fromRGBO(150, 198, 15, 1),
                                            size: 30,
                                          ),
                                    ),
                            ],
                          ),
                        ),
                        // const Spacer(flex: 3),
                        const SizedBox(width: 5),
                        // Container(
                        //   width: 77,
                        //   height: 40,
                        //   decoration: const BoxDecoration(
                        //     borderRadius: BorderRadius.all(Radius.circular(5)),
                        //     color: Colors.white,
                        //   ),
                        //   child: Row(
                        //     mainAxisAlignment:
                        //         widget.config.centerAlignModePicker == true
                        //             ? MainAxisAlignment.center
                        //             : MainAxisAlignment.start,
                        //     children: <Widget>[
                        //       // Flexible(
                        //       //   child: Text(
                        //       //     widget.title2,
                        //       //     overflow: TextOverflow.ellipsis,
                        //       //     style: const TextStyle(
                        //       //         color: Colors.black,
                        //       //         fontWeight: FontWeight.w700,
                        //       //         fontSize: 16),
                        //       //     // widget.config.controlsTextStyle ??
                        //       //     //     textTheme.titleSmall?.copyWith(
                        //       //     //       color: controlColor,
                        //       //     //     ),
                        //       //   ),
                        //       // ),
                        //       widget.config.disableModePicker == true
                        //           ? const SizedBox()
                        //           : RotationTransition(
                        //               turns: _controller,
                        //               child: widget
                        //                       .config.customModePickerIcon ??
                        //                   const Icon(
                        //                     Icons.arrow_drop_down,
                        //                     color:
                        //                         Color.fromRGBO(150, 198, 15, 1),
                        //                     size: 30,
                        //                   ),
                        //             ),
                        //     ],
                        //   ),
                        // ),
                      ],
                    ),
                  ),
                ),
              ),
            ),
          ),
          if (widget.mode == DatePickerMode.day)
            // Give space for the prev/next month buttons that are underneath this row
            SizedBox(width: datePickerOffsetPadding),
        ],
      ),
    );
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }
}
